package pomodoro

import (
	"git.smsvc.net/pomodoro/GoTomato/internal/broadcast"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"github.com/gorilla/websocket"
	"time"
)

// startTimer runs the countdown and broadcasts every second.
func startTimer(clients map[*websocket.Conn]bool, remainingSeconds int, mode string, session int) bool {
	for remainingSeconds > 0 {
		select {
		case <-pomodoroResetChannel:
			return false
		case <-pomodoroPauseChannel:
			mu.Lock()
			pomodoroPaused = true
			mu.Unlock()
		case <-pomodoroResumeChannel:
			mu.Lock()
			pomodoroPaused = false
			mu.Unlock()
		default:
			// Broadcast the current state to all clients
			if !pomodoroPaused {
				broadcast.BroadcastMessage(clients, models.BroadcastMessage{
					Mode:       mode,
					Session:    session,
					MaxSession: sessions,
					TimeLeft:   remainingSeconds,
				})
				time.Sleep(time.Second)
				remainingSeconds--
			}
		}
	}

	// Final broadcast when time reaches zero
	broadcast.BroadcastMessage(clients, models.BroadcastMessage{
		Mode:       mode,
		Session:    session,
		MaxSession: sessions,
		TimeLeft:   0,
	})

	return true
}
